==> elm-ts-0.5.3.tgz: package/es6/Debug/Navigation.js <==
/**
 * This module makes available a debugging utility for `elm-ts` applications running `Navigation` programs.
 *
 * `elm-ts` ships with a [Redux DevTool Extension](https://github.com/zalmoxisus/redux-devtools-extension) integration, falling back to a simple debugger via standard browser's [`console`](https://developer.mozilla.org/en-US/docs/Web/API/Console) in case the extension is not available.
 *
 * **Note:** debugging is to be considered unsafe by design so it should be used only in **development**.
 *
 * This is an example of usage:
 * ```ts
 * import {react, cmd} from 'elm-ts'
 * import {programWithDebugger} from 'elm-ts/lib/Debug/Navigation'
 * import {Location, program} from 'elm-ts/lib/Navigation'
 * import {render} from 'react-dom'
 *
 * type Model = number
 * type Msg = 'INCREMENT' | 'DECREMENT'
 *
 * declare function locationToMsg(location: Location): Msg
 * declare function init(location: Location): [Model, cmd.none]
 * declare function update(msg: Msg, model: Model): [Model, cmd.Cmd<Msg>]
 * declare function view(model: Model): react.Html<Msg>
 *
 * const program = process.NODE_ENV === 'production' ? program : programWithDebugger
 *
 * const main = program(locationToMsg, init, update, view)
 *
 * react.run(main, dom => render(document.getElementById('app')))
 * ```
 *
 * @since 0.5.3
 */
import * as H from 'history';
import { BehaviorSubject } from 'rxjs';
import { program } from '../Navigation';
import { debugInit, runDebugger, updateWithDebug } from './commons';
/**
 * Adds a debugging capability to a generic `Navigation` `Program`.
 *
 * It tracks every `Message` dispatched and resulting `Model` update.
 *
 * It also lets directly updating the application's state with a special `Message` of type:
 *
 * ```ts
 * {
 *   type: '__DebugUpdateModel__'
 *   payload: Model
 * }
 * ```
 *
 * or applying a message with:
 * ```ts
 * {
 *   type: '__DebugApplyMsg__';
 *   payload: Msg
 * }
 * ```
 * @since 0.5.3
 */
export function programWithDebugger(locationToMessage, init, update, view, subscriptions) {
    const history = H.createHashHistory(); // this is needed only to generate init model for debug$ :S
    const Debugger = runDebugger(window);
    const initModel = init(history.location)[0];
    const debug$ = new BehaviorSubject([debugInit(), initModel]);
    const p = program(locationToMessage, init, updateWithDebug(debug$, update), view, subscriptions);
    // --- Run the debugger
    // --- we need to make a type assertion for `dispatch` because we cannot change the intrinsic `msg` type of `program`;
    // --- otherwise `programWithDebugger` won't be usable as a transparent extension/substitution of `Html`'s programs
    Debugger({ debug$, init: initModel, dispatch: p.dispatch })();
    return p;
}
/**
 * Same as `programWithDebugger()` but with `Flags` that can be passed when the `Program` is created in order to manage initial values.
 * @since 0.5.3
 */
export function programWithDebuggerWithFlags(locationToMessage, init, update, view, subscriptions) {
    return flags => programWithDebugger(locationToMessage, init(flags), update, view, subscriptions);
}

==> elm-ts-0.5.4.tgz: package/es6/Debug/Navigation.js <==
/**
 * This module makes available a debugging utility for `elm-ts` applications running `Navigation` programs.
 *
 * `elm-ts` ships with a [Redux DevTool Extension](https://github.com/zalmoxisus/redux-devtools-extension) integration, falling back to a simple debugger via standard browser's [`console`](https://developer.mozilla.org/en-US/docs/Web/API/Console) in case the extension is not available.
 *
 * **Note:** debugging is to be considered unsafe by design so it should be used only in **development**.
 *
 * This is an example of usage:
 * ```ts
 * import {react, cmd} from 'elm-ts'
 * import {programWithDebugger} from 'elm-ts/lib/Debug/Navigation'
 * import {Location, program} from 'elm-ts/lib/Navigation'
 * import {render} from 'react-dom'
 *
 * type Model = number
 * type Msg = 'INCREMENT' | 'DECREMENT'
 *
 * declare function locationToMsg(location: Location): Msg
 * declare function init(location: Location): [Model, cmd.none]
 * declare function update(msg: Msg, model: Model): [Model, cmd.Cmd<Msg>]
 * declare function view(model: Model): react.Html<Msg>
 *
 * const program = process.NODE_ENV === 'production' ? program : programWithDebugger
 *
 * const main = program(locationToMsg, init, update, view)
 *
 * react.run(main, dom => render(document.getElementById('app')))
 * ```
 *
 * @since 0.5.3
 */
import * as H from 'history';
import { BehaviorSubject, EMPTY } from 'rxjs';
import { program } from '../Navigation';
import { debugInit, runDebugger, updateWithDebug } from './commons';
/**
 * Adds a debugging capability to a generic `Navigation` `Program`.
 *
 * It tracks every `Message` dispatched and resulting `Model` update.
 *
 * It also lets directly updating the application's state with a special `Message` of type:
 *
 * ```ts
 * {
 *   type: '__DebugUpdateModel__'
 *   payload: Model
 * }
 * ```
 *
 * or applying a message with:
 * ```ts
 * {
 *   type: '__DebugApplyMsg__';
 *   payload: Msg
 * }
 * ```
 * @since 0.5.3
 */
export function programWithDebugger(locationToMessage, init, update, view, subscriptions) {
    return createProgram(EMPTY, locationToMessage, init, update, view, subscriptions);
}
/**
 * A function that requires an `Observable` and returns a `programWithDebugger()` function: the underlying debugger will stop when the `Observable` emits a value.
 * @since 0.5.4
 */
export function programWithDebuggerWithStop(stopDebuggerOn) {
    return (locationToMessage, init, update, view, subscriptions) => createProgram(stopDebuggerOn, locationToMessage, init, update, view, subscriptions);
}
/**
 * Same as `programWithDebugger()` but with `Flags` that can be passed when the `Program` is created in order to manage initial values.
 * @since 0.5.3
 */
export function programWithDebuggerWithFlags(locationToMessage, init, update, view, subscriptions) {
    return flags => programWithDebugger(locationToMessage, init(flags), update, view, subscriptions);
}
/**
 * Same as `programWithDebuggerWithStop()` but with `Flags` that can be passed when the `Program` is created in order to manage initial values.
 * @since 0.5.4
 */
export function programWithDebuggerWithFlagsWithStop(stopDebuggerOn) {
    return (locationToMessage, init, update, view, subscriptions) => flags => createProgram(stopDebuggerOn, locationToMessage, init(flags), update, view, subscriptions);
}
// --- Internal
function createProgram(stopDebuggerOn, locationToMessage, init, update, view, subscriptions) {
    const history = H.createHashHistory(); // this is needed only to generate init model for debug$ :S
    const Debugger = runDebugger(window, stopDebuggerOn);
    const initModel = init(history.location)[0];
    const debug$ = new BehaviorSubject([debugInit(), initModel]);
    const p = program(locationToMessage, init, updateWithDebug(debug$, update), view, subscriptions);
    // --- Run the debugger
    // --- we need to make a type assertion for `dispatch` because we cannot change the intrinsic `msg` type of `program`;
    // --- otherwise `programWithDebugger` won't be usable as a transparent extension/substitution of `Html`'s programs
    Debugger({
        debug$,
        init: initModel,
        dispatch: p.dispatch
    })();
    return p;
}
